@@ -1,3 +1,8 @@
+#[cfg(feature = "tokio")]
+extern crate runtime_tokio as tokio;
+#[cfg(feature = "async-std")]
+extern crate runtime_async_std as async_std;
+
 use futures::stream::StreamExt;
 
 use unrar_async::Archive;
